#
# spec file for package libgee06
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2010 Luis Medinas, Portugal
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name libgee
Name:           libgee06
Version:        0.6.6
Release:        6.2
Summary:        GObject-based library providing commonly used data structures
License:        LGPL-2.1-or-later
Group:          Development/Libraries/GNOME
URL:            https://live.gnome.org/Libgee
Source:         http://download.gnome.org/sources/libgee/0.6/%{_name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE libgee-gir.patch dimstar@opensuse.org -- The typelib file should not reference libgee, but libgee.so.2. The patch is not clean for upstream, but discussion has started at bgo#667529.
Patch0:         libgee-gir.patch
BuildRequires:  glib2-devel
BuildRequires:  gobject-introspection-devel
BuildRequires:  vala

%description
Libgee is a collection library providing GObject-based interfaces and
classes for commonly used data structures.

%package -n libgee2
Summary:        GObject-based library providing commonly used data structures
Group:          System/Libraries
%if 0%{?suse_version} <= 1210
Requires:       typelib-1_0-Gee-1_0
%endif

%description -n libgee2
Libgee is a collection library providing GObject-based interfaces and
classes for commonly used data structures.

%package -n typelib-1_0-Gee-1_0
Summary:        GObject-based library providing commonly used data structures -- Introspection bindings
Group:          System/Libraries

%description -n typelib-1_0-Gee-1_0
Libgee is a collection library providing GObject-based interfaces and
classes for commonly used data structures.

This package provides the GObject Introspection bindings for libgee.

%package -n libgee06-devel
Summary:        GObject-based library providing useful data structures - Development Files
Group:          Development/Libraries/GNOME
Requires:       libgee2 = %{version}
Requires:       typelib-1_0-Gee-1_0 = %{version}

%description -n libgee06-devel
Libgee is a collection library providing GObject-based interfaces and
classes for commonly used data structures.

%prep
%autosetup -n %{_name}-%{version} -p1

%build
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libgee2 -p /sbin/ldconfig
%postun -n libgee2 -p /sbin/ldconfig

%files -n libgee2
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/*.so.*

%files -n typelib-1_0-Gee-1_0
%{_libdir}/girepository-1.0/Gee-1.0.typelib

%files -n libgee06-devel
%{_includedir}/gee-1.0/
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/*.gir
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/*.vapi

%changelog
* Thu Feb  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Prepare for RPM 4.20: use autosetup.
* Tue Mar 19 2013 dimstar@opensuse.org
- Rename package to libgee06, in order to have libgee 0.9.x as the
  'primary' libgee package.
* Sat Oct 20 2012 zaitor@opensuse.org
- Update to version 0.6.6:
  + Fix iterator.remove in PriorityQueue.
* Wed Aug 15 2012 dimstar@opensuse.org
- Update to version 0.6.5:
  + Prevent hashtables from resizing during iteration.
* Fri Feb 24 2012 vuntz@opensuse.org
- Update to version 0.6.4:
  + Fix compilation with vala master
  + Fix creation of GObject introspection files
- Changes from version 0.6.3:
  + Fix buffer underflow.
- Changes from version 0.6.2.1:
  + Add check-news to AM_INIT_AUTOMAKE
- Changes from version 0.6.2:
  + Fix adding second element to priority queue.
  + Fix problem with key used in range is freed.
- Rebase libgee-gir.patch.
* Tue Jan 10 2012 vuntz@opensuse.org
- Add a typelib-1_0-Gee-1_0 Requires to libgee2 subpackage on 12.1
  and earlier: this shouldn't be needed, but unfortunately, this is
  needed for people using GNOME:Apps with 12.1. Otherwise,
  typelib-1_0-Gee-1_0 doesn't get installed and gnome-shell will
  stop working.
* Tue Dec 13 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-Gee-1_0 subpackage.
- Add typelib-1_0-Gee-1_0 Requires to libgee-devel subpackage.
- Add libgee-gir.patch: Make sure the typelib file references the
  real library name.
- Drop glib2-devel Requires from -devel package: it is
  automatically added the pkgconfig()-way.
* Mon Mar 21 2011 dimstar@opensuse.org
- Update to version 0.6.1:
  +  Fix memory leaks in LinkedList.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 0.6.0:
  + Fix compiler warning.
* Thu Sep 16 2010 vuntz@opensuse.org
- Update to version 0.5.3:
  + Fix memory leaks in TimSort and LinkedList.
  + Bug fixes in TreeMap and TreeSet.
* Wed Aug  4 2010 dimstar@opensuse.org
- Update to version 0.5.2:
  + Build system enhancements to conform Gnome's style.
  + Bug fixes in TreeSet, TreeMap and Collection.to_array.
  + Deprecated Map methods marked with [Deprecated].
- Move *.gir to -devel package and package also the typelib.
* Mon Jun 21 2010 dimstar@opensuse.org
- Update to version 0.5.1:
  + Bug fixes in HashMultiSet, TimSort, TreeMap, TreeMultiSet, and
    TreeSet.
  + Fix build with Vala 0.8.0 and later
  + Fix build on Windows
  + Fix subprocess handling in test infrastructure
* Wed Jan  6 2010 lmedinas@opensuse.org
- Initial package for openSUSE.
